@@ -4,7 +4,7 @@ import hashlib
 
 def main():
     for arg in sys.argv[1:]:
-        for name in glob.glob(arg):
+        for name in sorted(glob.glob(arg)):
             m = hashlib.md5()
             with open(name, 'rb') as fid:
                 m.update(fid.read())
