@@ -254,20 +254,16 @@ def run():
 
 
     c.addPyMethod('__repr__', '(self)', """\
-        from six import PY2
         if self.IsValid():
             f = self.Format()
-            if PY2: f = f.encode('utf-8')
             return '<wx.DateTime: "%s">' % f
         else:
             return '<wx.DateTime: \"INVALID\">'
         """)
 
     c.addPyMethod('__str__', '(self)', """\
-        from six import PY2
         if self.IsValid():
             f = self.Format()
-            if PY2: f = f.encode('utf-8')
             return f
         else:
             return "INVALID DateTime"
@@ -315,7 +311,9 @@ def run():
 
     # Add some code (like MappedTypes) to automatically convert from a Python
     # datetime.date or a datetime.datetime object
-    c.convertFromPyObject = """\
+    c.convertFromPyObject = tools.AutoConversionInfo(
+        ('datetime', 'date', ),
+        """\
         // Code to test a PyObject for compatibility with wxDateTime
         if (!sipIsErr) {
             if (sipCanConvertToType(sipPy, sipType_wxDateTime, SIP_NO_CONVERTORS))
@@ -339,7 +337,7 @@ def run():
                 sipPy, sipType_wxDateTime, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));
 
         return 0;  // Not a new instance
-        """
+        """)
 
 
     #---------------------------------------------
