@@ -15,10 +15,6 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
@@ -584,7 +580,7 @@ extern int g_tab2[];
 bool Life::NextTic()
 {
     LifeCellBox  *c, *up, *dn, *lf, *rt;
-    wxUint32 t1, t2, t3, t4;
+    wxUint32 t1, t2;
     bool     changed = false;
 
     m_numcells = 0;
@@ -833,6 +829,7 @@ bool Life::NextTic()
         t1 = 0;
         t2 = 0;
 
+        wxUint32 t3, t4;
         t3 = c->m_live1;
         c->m_old1 = t3;
 
@@ -922,15 +919,15 @@ bool Life::NextTic()
 
 class LifeModule: public wxModule
 {
-DECLARE_DYNAMIC_CLASS(LifeModule)
+    wxDECLARE_DYNAMIC_CLASS(LifeModule);
 
 public:
-    LifeModule() {};
-    bool OnInit();
-    void OnExit();
+    LifeModule() {}
+    bool OnInit() wxOVERRIDE;
+    void OnExit() wxOVERRIDE;
 };
 
-IMPLEMENT_DYNAMIC_CLASS(LifeModule, wxModule)
+wxIMPLEMENT_DYNAMIC_CLASS(LifeModule, wxModule);
 
 bool LifeModule::OnInit()
 {
