@@ -118,7 +118,7 @@ wxCONSTRUCTOR_5( wxComboBox, wxWindow*, Parent, wxWindowID, Id, \
 
 #define BMP_BUTTON_MARGIN                       4
 
-#define DEFAULT_POPUP_HEIGHT                    400
+#define DEFAULT_POPUP_ITEMS                     21
 
 #define DEFAULT_TEXT_INDENT                     3
 
@@ -2161,8 +2161,13 @@ void wxComboCtrlBase::ShowPopup()
 
     wxASSERT( !m_popup || m_popup == popup ); // Consistency check.
 
+    int heightPopup = m_heightPopup;
+    if (heightPopup <= 0)
+        // estimated height for a row containig text
+        heightPopup = DEFAULT_POPUP_ITEMS * (GetCharHeight() + FromDIP(4));
+
     wxSize adjustedSize = m_popupInterface->GetAdjustedSize(widthPopup,
-                                                            m_heightPopup<=0?DEFAULT_POPUP_HEIGHT:m_heightPopup,
+                                                            heightPopup,
                                                             maxHeightPopup);
 
     popup->SetSize(adjustedSize);
