@@ -25,17 +25,8 @@
 #include "wx/gtk/private/timer.h"
 #include "wx/evtloop.h"
 
-#include "wx/gtk/private/wrapgtk.h"
+#include "wx/gtk/private/wrapgdk.h"
 #include "wx/gtk/private/backend.h"
-#ifdef GDK_WINDOWING_WAYLAND
-#include <gdk/gdkwayland.h>
-#endif
-#ifdef GDK_WINDOWING_WIN32
-#include <gdk/gdkwin32.h>
-#endif
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#endif
 
 #if wxDEBUG_LEVEL
     #include "wx/gtk/assertdlg_gtk.h"
@@ -314,7 +305,7 @@ protected:
             return;
         }
 
-        // Also ignore frames which don't have neither the function name nor
+        // Also ignore frames which have neither the function name nor
         // the file name, showing them in the dialog wouldn't provide any
         // useful information.
         if ( name.empty() && frame.GetFileName().empty() )
@@ -431,18 +422,33 @@ bool wxGUIAppTraits::ShowAssertDialog(const wxString& msg)
 wxString wxGUIAppTraits::GetDesktopEnvironment() const
 {
     wxString de = wxSystemOptions::GetOption(wxT("gtk.desktop"));
+    if (!de.empty())
+        return de;
+
+    de = wxGetenv(wxS("XDG_CURRENT_DESKTOP"));
+    if (!de.empty())
+    {
+        // Can be a colon separated list according to
+        // https://wiki.archlinux.org/title/Environment_variables#Examples
+        de = de.BeforeFirst(':');
+    }
 #if wxUSE_DETECT_SM
     if ( de.empty() )
     {
-        static const wxString s_SM = GetSM().Upper();
-
-        if (s_SM.Contains(wxT("GNOME")))
-            de = wxT("GNOME");
-        else if (s_SM.Contains(wxT("KDE")))
-            de = wxT("KDE");
+        static const wxString s_SM(GetSM());
+        de = s_SM;
+        de.Replace(wxS("-session"), wxString());
     }
 #endif // wxUSE_DETECT_SM
 
+    de.MakeUpper();
+    if (de.Contains(wxS("GNOME")))
+        de = wxS("GNOME");
+    else if (de.Contains(wxS("KDE")))
+        de = wxS("KDE");
+    else if (de.Contains(wxS("XFCE")))
+        de = wxS("XFCE");
+
     return de;
 }
 
