@@ -39,6 +39,7 @@
 #endif // WX_PRECOMP
 
 #include "wx/msw/private.h"
+#include "wx/msw/private/menu.h"
 
 #include "wx/generic/statusbr.h"
 
@@ -707,7 +708,7 @@ void wxFrame::IconizeChildFrames(bool bIconize)
                 frame->m_wasMinimized = frame->IsIconized();
             }
 
-            // note that we shouldn't touch the hidden frames neither because
+            // note that we shouldn't touch the hidden frames either because
             // iconizing/restoring them would show them as a side effect
             if ( !frame->m_wasMinimized && frame->IsShown() )
                 frame->Iconize(bIconize);
@@ -764,7 +765,7 @@ bool wxFrame::HandleSize(int WXUNUSED(x), int WXUNUSED(y), WXUINT id)
         case SIZE_RESTORED:
         case SIZE_MAXIMIZED:
             // only do it it if we were iconized before, otherwise resizing the
-            // parent frame has a curious side effect of bringing it under it's
+            // parent frame has a curious side effect of bringing it under its
             // children
             if ( m_showCmd != SW_MINIMIZE )
                 break;
@@ -833,6 +834,58 @@ bool wxFrame::HandleCommand(WXWORD id, WXWORD cmd, WXHWND control)
     return wxFrameBase::HandleCommand(id, cmd, control);
 }
 
+bool
+HandleMenuMessage(WXLRESULT* result,
+                  wxWindow* w,
+                  WXUINT nMsg,
+                  WXWPARAM wParam,
+                  WXLPARAM lParam)
+{
+    using namespace wxMSWMenuImpl;
+
+    switch ( nMsg )
+    {
+        case WM_MENUBAR_MEASUREMENUITEM:
+            if ( MenuBarMeasureMenuItem* const measureMenuItem = (MenuBarMeasureMenuItem*)lParam )
+            {
+                // We only need to handle this message for a workaround when
+                // using non-standard DPI.
+                if ( !(w->GetDPIScaleFactor() > 1.0) )
+                    break;
+
+                MEASUREITEMSTRUCT& mis = measureMenuItem->mis;
+
+                // Just a sanity check.
+                if ( mis.CtlType != ODT_MENU )
+                    break;
+
+                HWND hwnd = GetHwndOf(w);
+
+                WinStruct<MENUBARINFO> mbi;
+                if ( !::GetMenuBarInfo(hwnd, OBJID_MENU, 0, &mbi) )
+                {
+                    wxLogLastError("GetMenuBarInfo");
+                    break;
+                }
+
+                *result = w->MSWDefWindowProc(nMsg, wParam, lParam);
+
+                // Scale the horizontal padding of menu bar menus and the
+                // vertical padding of menu items with the DPI scaling factor
+                // as Windows doesn't do it.
+                if ( mbi.hMenu == measureMenuItem->mbdm.hmenu )
+                    mis.itemWidth += w->FromDIP(14) - 14;
+                else
+                    mis.itemHeight += w->FromDIP(6) - 6;
+
+                return true;
+            }
+            break;
+    }
+
+    return false;
+}
+
 // ---------------------------------------------------------------------------
 // the window proc for wxFrame
 // ---------------------------------------------------------------------------
@@ -842,6 +895,12 @@ WXLRESULT wxFrame::MSWWindowProc(WXUINT message, WXWPARAM wParam, WXLPARAM lPara
     WXLRESULT rc = 0;
     bool processed = false;
 
+    if ( GetMenuBar() &&
+          HandleMenuMessage(&rc, this, message, wParam, lParam) )
+    {
+        return rc;
+    }
+
     switch ( message )
     {
         case WM_CLOSE:
