@@ -34,9 +34,6 @@
 // ============================================================================
 
 
-#include "wx/cocoa/autorelease.h"
-#include "wx/cocoa/string.h"
-
 #if wxOSX_USE_EXPERIMENTAL_FONTDIALOG
 
 #import <Foundation/Foundation.h>
@@ -44,6 +41,66 @@
 
 #include "wx/osx/private.h"
 
+
+@interface wxFontPanelDelegate : NSObject<NSWindowDelegate>
+{
+    @public
+    bool m_isUnderline;
+    bool m_isStrikethrough;
+}
+
+// Delegate methods
+- (id)init;
+- (void)changeAttributes:(id)sender;
+- (void)changeFont:(id)sender;
+@end // interface wxNSFontPanelDelegate : NSObject
+
+
+
+@implementation wxFontPanelDelegate : NSObject
+
+- (id)init
+{
+    if (self = [super init])
+    {
+        m_isUnderline = false;
+        m_isStrikethrough = false;
+    }
+    return self;
+}
+
+- (void)changeAttributes:(id)sender
+{
+    NSDictionary *dummyAttribs = [NSDictionary dictionaryWithObjectsAndKeys:
+                                   [NSNumber numberWithInt:m_isUnderline?NSUnderlineStyleSingle:NSUnderlineStyleNone], NSUnderlineStyleAttributeName,
+                                   [NSNumber numberWithInt:m_isStrikethrough?NSUnderlineStyleSingle:NSUnderlineStyleNone], NSStrikethroughStyleAttributeName,
+                                   nil];
+    NSDictionary *attribs = [sender convertAttributes:dummyAttribs];
+
+    m_isUnderline = m_isStrikethrough = false;
+    for (id key in attribs) {
+        NSNumber *number = static_cast<NSNumber *>([attribs objectForKey:key]);
+        if ([key isEqual:NSUnderlineStyleAttributeName]) {
+            m_isUnderline = [number intValue] != NSUnderlineStyleNone;
+        } else if ([key isEqual:NSStrikethroughStyleAttributeName]) {
+            m_isStrikethrough = [number intValue] != NSUnderlineStyleNone;
+        }
+    }
+
+    NSDictionary *attributes = [NSDictionary dictionaryWithObjectsAndKeys:
+                                [NSNumber numberWithInt:m_isUnderline?NSUnderlineStyleSingle:NSUnderlineStyleNone], NSUnderlineStyleAttributeName,
+                                [NSNumber numberWithInt:m_isStrikethrough?NSUnderlineStyleSingle:NSUnderlineStyleNone], NSStrikethroughStyleAttributeName,
+                                nil];
+    [[NSFontManager sharedFontManager] setSelectedAttributes:attributes isMultiple:false];
+}
+- (void)changeFont:(id)sender
+{
+    NSFont *dummyFont = [NSFont userFontOfSize:12.0];
+    [[NSFontPanel sharedFontPanel] setPanelFont:[sender convertFont:dummyFont] isMultiple:NO];
+    [[NSFontManager sharedFontManager] setSelectedFont:[sender convertFont:dummyFont] isMultiple:false];
+}
+@end
+
 @interface wxMacFontPanelAccView : NSView
 {
     BOOL m_okPressed ;
@@ -63,37 +120,38 @@
 @implementation wxMacFontPanelAccView : NSView
 - (id)initWithFrame:(NSRect)rectBox
 {
-    [super initWithFrame:rectBox];
+    if ( self = [super initWithFrame:rectBox] )
+    {
+        wxCFStringRef cfOkString( wxT("OK"), wxLocale::GetSystemEncoding() );
+        wxCFStringRef cfCancelString( wxT("Cancel"), wxLocale::GetSystemEncoding() );
 
-    wxCFStringRef cfOkString( wxT("OK"), wxLocale::GetSystemEncoding() );
-    wxCFStringRef cfCancelString( wxT("Cancel"), wxLocale::GetSystemEncoding() );
+        NSRect rectCancel = NSMakeRect( (CGFloat) 10.0 , (CGFloat)10.0 , (CGFloat)82  , (CGFloat)24 );
+        NSRect rectOK = NSMakeRect( (CGFloat)100.0 , (CGFloat)10.0 , (CGFloat)82  , (CGFloat)24 );
 
-    NSRect rectCancel = NSMakeRect( (CGFloat) 10.0 , (CGFloat)10.0 , (CGFloat)82  , (CGFloat)24 );
-    NSRect rectOK = NSMakeRect( (CGFloat)100.0 , (CGFloat)10.0 , (CGFloat)82  , (CGFloat)24 );
+        NSButton* cancelButton = [[NSButton alloc] initWithFrame:rectCancel];
+        [cancelButton setTitle:(NSString*)wxCFRetain((CFStringRef)cfCancelString)];
+        [cancelButton setBezelStyle:NSRoundedBezelStyle];
+        [cancelButton setButtonType:NSMomentaryPushInButton];
+        [cancelButton setAction:@selector(cancelPressed:)];
+        [cancelButton setTarget:self];
+        m_cancelButton = cancelButton ;
 
-    NSButton* cancelButton = [[NSButton alloc] initWithFrame:rectCancel];
-    [cancelButton setTitle:(NSString*)wxCFRetain((CFStringRef)cfCancelString)];
-    [cancelButton setBezelStyle:NSRoundedBezelStyle];
-    [cancelButton setButtonType:NSMomentaryPushInButton];
-    [cancelButton setAction:@selector(cancelPressed:)];
-    [cancelButton setTarget:self];
-    m_cancelButton = cancelButton ;
-
-    NSButton* okButton = [[NSButton alloc] initWithFrame:rectOK];
-    [okButton setTitle:(NSString*)wxCFRetain((CFStringRef)cfOkString)];
-    [okButton setBezelStyle:NSRoundedBezelStyle];
-    [okButton setButtonType:NSMomentaryPushInButton];
-    [okButton setAction:@selector(okPressed:)];
-    [okButton setTarget:self];
-    // doesn't help either, the button is not highlighted after a color dialog has been used
-    // [okButton setKeyEquivalent:@"\r"];
-    m_okButton = okButton ;
+        NSButton* okButton = [[NSButton alloc] initWithFrame:rectOK];
+        [okButton setTitle:(NSString*)wxCFRetain((CFStringRef)cfOkString)];
+        [okButton setBezelStyle:NSRoundedBezelStyle];
+        [okButton setButtonType:NSMomentaryPushInButton];
+        [okButton setAction:@selector(okPressed:)];
+        [okButton setTarget:self];
+        // doesn't help either, the button is not highlighted after a color dialog has been used
+        // [okButton setKeyEquivalent:@"\r"];
+        m_okButton = okButton ;
 
 
-    [self addSubview:cancelButton];
-    [self addSubview:okButton];
+        [self addSubview:cancelButton];
+        [self addSubview:okButton];
 
-    [self resetFlags];
+        [self resetFlags];
+    }
     return self;
 }
 
@@ -146,17 +204,14 @@ int RunMixedFontDialog(wxFontDialog* dialog)
 #endif
     int retval = wxID_CANCEL ;
 
-    wxAutoNSAutoreleasePool pool;
+    wxMacAutoreleasePool pool;
 
     // setting up the ok/cancel buttons
     NSFontPanel* fontPanel = [NSFontPanel sharedFontPanel] ;
 
-    // adjust modality for carbon environment
-#if wxOSX_USE_CARBON
-    WindowRef carbonWindowRef = (WindowRef)[fontPanel windowRef] ;
-    SetWindowModality(carbonWindowRef, kWindowModalityAppModal , 0) ;
-    SetWindowGroup(carbonWindowRef , GetWindowGroupOfClass(kMovableModalWindowClass));
-#endif
+    wxFontPanelDelegate* theFPDelegate = [[wxFontPanelDelegate alloc] init];
+    [fontPanel setDelegate:theFPDelegate];
+
 
     [fontPanel setFloatingPanel:NO] ;
     [[fontPanel standardWindowButton:NSWindowCloseButton] setEnabled:NO] ;
@@ -183,16 +238,27 @@ int RunMixedFontDialog(wxFontDialog* dialog)
     {
         font = fontdata.m_initialFont ;
     }
+    theFPDelegate->m_isStrikethrough = font.GetStrikethrough();
+    theFPDelegate->m_isUnderline = font.GetUnderlined();
 
     [[NSFontPanel sharedFontPanel] setPanelFont: font.OSXGetNSFont() isMultiple:NO];
+    [[NSFontManager sharedFontManager] setSelectedFont:font.OSXGetNSFont() isMultiple:false];
+
+    NSDictionary *attributes = [NSDictionary dictionaryWithObjectsAndKeys:
+                                [NSNumber numberWithInt:font.GetUnderlined()
+                                    ? NSUnderlineStyleSingle
+                                    : NSUnderlineStyleNone],
+                                NSUnderlineStyleAttributeName,
+                                [NSNumber numberWithInt:font.GetStrikethrough()
+                                    ? NSUnderlineStyleSingle
+                                    : NSUnderlineStyleNone],
+                                NSStrikethroughStyleAttributeName,
+                                nil];
+
+    [[NSFontManager sharedFontManager] setSelectedAttributes:attributes isMultiple:false];
 
     if(fontdata.m_fontColour.IsOk())
-        [[NSColorPanel sharedColorPanel] setColor:
-            [NSColor colorWithCalibratedRed:fontdata.m_fontColour.Red() / 255.0
-                                        green:fontdata.m_fontColour.Green() / 255.0
-                                        blue:fontdata.m_fontColour.Blue() / 255.0
-                                        alpha:1.0]
-        ];
+        [[NSColorPanel sharedColorPanel] setColor: fontdata.m_fontColour.OSXGetNSColor()];
     else
         [[NSColorPanel sharedColorPanel] setColor:[NSColor blackColor]];
 #endif
@@ -201,31 +267,25 @@ int RunMixedFontDialog(wxFontDialog* dialog)
     
     // if we don't reenable it, FPShowHideFontPanel does not work
     [[fontPanel standardWindowButton:NSWindowCloseButton] setEnabled:YES] ;
-#if wxOSX_USE_CARBON
-    if( FPIsFontPanelVisible())
-        FPShowHideFontPanel() ;
-#else
+    // we must pick the selection before closing, otherwise a native textcontrol interferes
+    NSFont* theFont = [fontPanel panelConvertFont:[NSFont userFontOfSize:0]];
     [fontPanel close];
-#endif
 
     if ( [accessoryView closedWithOk])
     {
 #if wxOSX_USE_COCOA
-        NSFont* theFont = [fontPanel panelConvertFont:[NSFont userFontOfSize:0]];
-
-        fontdata.m_chosenFont = wxFont( theFont );
+        fontdata.m_chosenFont = wxFont(theFont);
+        // copy the attributes not contained in a native CTFont
+        fontdata.m_chosenFont.SetUnderlined(theFPDelegate->m_isUnderline);
+        fontdata.m_chosenFont.SetStrikethrough(theFPDelegate->m_isStrikethrough);
 
         //Get the shared color panel along with the chosen color and set the chosen color
-        NSColor* theColor = [[[NSColorPanel sharedColorPanel] color] colorUsingColorSpaceName:NSCalibratedRGBColorSpace];
-
-        fontdata.m_fontColour.Set((unsigned char) ([theColor redComponent] * 255.0),
-                                    (unsigned char) ([theColor greenComponent] * 255.0),
-                                    (unsigned char) ([theColor blueComponent] * 255.0));
+        fontdata.m_fontColour = wxColour([[NSColorPanel sharedColorPanel] color]);
 #endif
         retval = wxID_OK ;
     }
     [fontPanel setAccessoryView:nil];
-
+    [theFPDelegate release];
     return retval ;
 }
 
@@ -233,7 +293,7 @@ int RunMixedFontDialog(wxFontDialog* dialog)
 
 #if USE_NATIVE_FONT_DIALOG_FOR_MACOSX
 
-IMPLEMENT_DYNAMIC_CLASS(wxFontDialog, wxDialog)
+wxIMPLEMENT_DYNAMIC_CLASS(wxFontDialog, wxDialog);
 
 // Cocoa headers
 
@@ -262,9 +322,11 @@ IMPLEMENT_DYNAMIC_CLASS(wxFontDialog, wxDialog)
 
 - (id)init
 {
-    [super init];
-    m_bIsClosed = false;
-
+    if ( self = [super init] )
+    {
+        m_bIsClosed = false;
+    }
+    
     return self;
 }
 
@@ -306,10 +368,11 @@ IMPLEMENT_DYNAMIC_CLASS(wxFontDialog, wxDialog)
 
 - (id)init
 {
-    [super init];
-    m_bIsClosed = false;
-    m_bIsOpen = false;
-
+    if ( self = [super init] )
+    {
+        m_bIsClosed = false;
+        m_bIsOpen = false;
+    }
     return self;
 }
 
@@ -394,39 +457,15 @@ bool wxFontDialog::Create(wxWindow *parent)
     //NSFontDialog to that font
     if (thewxfont.IsOk())
     {
-        NSFontTraitMask theMask = 0;
-
-        if(thewxfont.GetStyle() == wxFONTSTYLE_ITALIC)
-            theMask |= NSItalicFontMask;
-
-        if(thewxfont.IsFixedWidth())
-            theMask |= NSFixedPitchFontMask;
-
-        NSFont* theDefaultFont =
-            [[NSFontManager sharedFontManager] fontWithFamily:
-                                                    wxNSStringWithWxString(thewxfont.GetFaceName())
-                                            traits:theMask
-                                            weight:thewxfont.GetWeight() == wxBOLD ? 9 :
-                                                    thewxfont.GetWeight() == wxLIGHT ? 0 : 5
-                                            size: (float)(thewxfont.GetPointSize())
-            ];
-
-        wxASSERT_MSG(theDefaultFont, wxT("Invalid default font for wxCocoaFontDialog!"));
-
         //Apple docs say to call NSFontManager::setSelectedFont
         //However, 10.3 doesn't seem to create the font panel
         //is this is done, so create it ourselves
-        [[NSFontPanel sharedFontPanel] setPanelFont:theDefaultFont isMultiple:NO];
-
+        [[NSFontPanel sharedFontPanel] setPanelFont:thewxfont.OSXGetNSFont() isMultiple:NO];
+        [[NSFontManager sharedFontManager] setSelectedFont:theDefaultFont isMultiple:false];
     }
 
     if(m_fontData.m_fontColour.IsOk())
-        [[NSColorPanel sharedColorPanel] setColor:
-            [NSColor colorWithCalibratedRed:m_fontData.m_fontColour.Red() / 255.0
-                                        green:m_fontData.m_fontColour.Green() / 255.0
-                                        blue:m_fontData.m_fontColour.Blue() / 255.0
-                                        alpha:1.0]
-        ];
+        [[NSColorPanel sharedColorPanel] setColor: fontdata.m_fontColour.OSXGetNSColor()];
     else
         [[NSColorPanel sharedColorPanel] setColor:[NSColor blackColor]];
 
@@ -474,7 +513,7 @@ int wxFontDialog::ShowModal()
     //  the color panel until the color panel closes, switching
     //  back to the font panel modal loop once it does close.
     //
-    wxDialog::OSXBeginModalDialog();
+    OSXBeginModalDialog();
     do
     {
         //
@@ -513,7 +552,7 @@ int wxFontDialog::ShowModal()
         //out of its modal loop because the color panel was
         //opened) return the font panel modal loop
     }while([theFPDelegate isClosed] == NO);
-    wxDialog::OSXEndModalDialog();
+    OSXEndModalDialog();
     
     //free up the memory for the delegates - we don't need them anymore
     [theFPDelegate release];
@@ -521,28 +560,13 @@ int wxFontDialog::ShowModal()
 
     //Get the font the user selected
     NSFont* theFont = [theFontPanel panelConvertFont:[NSFont userFontOfSize:0]];
-
-    //Get more information about the user's chosen font
-    NSFontTraitMask theTraits = [[NSFontManager sharedFontManager] traitsOfFont:theFont];
-    int theFontWeight = [[NSFontManager sharedFontManager] weightOfFont:theFont];
-    int theFontSize = (int) [theFont pointSize];
-
-    //Set the wx font to the appropriate data
-    if(theTraits & NSFixedPitchFontMask)
-        m_fontData.m_chosenFont.SetFamily(wxTELETYPE);
-
-    m_fontData.m_chosenFont.SetFaceName(wxStringWithNSString([theFont familyName]));
-    m_fontData.m_chosenFont.SetPointSize(theFontSize);
-    m_fontData.m_chosenFont.SetStyle(theTraits & NSItalicFontMask ? wxFONTSTYLE_ITALIC : 0);
-    m_fontData.m_chosenFont.SetWeight(theFontWeight < 5 ? wxLIGHT :
-                                    theFontWeight >= 9 ? wxBOLD : wxNORMAL);
-
+    m_fontData.m_chosenFont = wxFont(theFont);
+    // copy the attributes not contained in a native CTFont
+    m_fontData.m_chosenFont.SetUnderlined(theFPDelegate->m_isUnderline);
+    m_fontData.m_chosenFont.SetStrikethrough(theFPDelegate->m_isStrikethrough);
+    
     //Get the shared color panel along with the chosen color and set the chosen color
-    NSColor* theColor = [[theColorPanel color] colorUsingColorSpaceName:NSCalibratedRGBColorSpace];
-
-    m_fontData.m_fontColour.Set((unsigned char) ([theColor redComponent] * 255.0),
-                                (unsigned char) ([theColor greenComponent] * 255.0),
-                                (unsigned char) ([theColor blueComponent] * 255.0));
+    m_fontData.m_fontColour = wxColour([theColorPanel color]);
 
     //Friendly debug stuff
 #ifdef FONTDLGDEBUG
