@@ -514,7 +514,9 @@ void wxGUIEventLoop::EndModalSession()
     wxASSERT_MSG(m_modalSession != NULL, "no modal session active");
     
     wxASSERT_MSG(m_modalNestedLevel > 0, "incorrect modal nesting level");
-    
+
+    m_modalWindow = NULL;
+
     --m_modalNestedLevel;
     if ( m_modalNestedLevel == 0 )
     {
@@ -522,6 +524,7 @@ void wxGUIEventLoop::EndModalSession()
         m_modalSession = nil;
         if ( m_dummyWindow )
         {
+            [m_dummyWindow close];
             [m_dummyWindow release];
             m_dummyWindow = nil;
         }
@@ -546,8 +549,11 @@ void wxGUIEventLoop::EndModalSession()
         
         if ( m_dummyWindow != element.dummyWindow )
         {
-            if ( element.dummyWindow )
-                [element.dummyWindow release];
+            if ( m_dummyWindow )
+            {
+                [m_dummyWindow close];
+                [m_dummyWindow release];
+            }
 
             m_dummyWindow = element.dummyWindow;
         }
