@@ -10,9 +10,6 @@
 
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #if wxUSE_RIBBON
 
@@ -33,11 +30,11 @@
 
 wxDEFINE_EVENT(wxEVT_RIBBONPANEL_EXTBUTTON_ACTIVATED, wxRibbonPanelEvent);
 
-IMPLEMENT_DYNAMIC_CLASS(wxRibbonPanelEvent, wxCommandEvent)
+wxIMPLEMENT_DYNAMIC_CLASS(wxRibbonPanelEvent, wxCommandEvent);
 
-IMPLEMENT_CLASS(wxRibbonPanel, wxRibbonControl)
+wxIMPLEMENT_CLASS(wxRibbonPanel, wxRibbonControl);
 
-BEGIN_EVENT_TABLE(wxRibbonPanel, wxRibbonControl)
+wxBEGIN_EVENT_TABLE(wxRibbonPanel, wxRibbonControl)
     EVT_ENTER_WINDOW(wxRibbonPanel::OnMouseEnter)
     EVT_ERASE_BACKGROUND(wxRibbonPanel::OnEraseBackground)
     EVT_KILL_FOCUS(wxRibbonPanel::OnKillFocus)
@@ -46,7 +43,7 @@ BEGIN_EVENT_TABLE(wxRibbonPanel, wxRibbonControl)
     EVT_LEFT_DOWN(wxRibbonPanel::OnMouseClick)
     EVT_PAINT(wxRibbonPanel::OnPaint)
     EVT_SIZE(wxRibbonPanel::OnSize)
-END_EVENT_TABLE()
+wxEND_EVENT_TABLE()
 
 wxRibbonPanel::wxRibbonPanel() : m_expanded_dummy(NULL), m_expanded_panel(NULL)
 {
@@ -135,7 +132,7 @@ void wxRibbonPanel::CommonInit(const wxString& label, const wxBitmap& icon, long
     }
 
     SetAutoLayout(true);
-    SetBackgroundStyle(wxBG_STYLE_CUSTOM);
+    SetBackgroundStyle(wxBG_STYLE_PAINT);
     SetMinSize(wxSize(20, 20));
 }
 
@@ -227,14 +224,14 @@ void wxRibbonPanel::AddChild(wxWindowBase *child)
     // for children of the window. The panel wants to be in the hovered state
     // whenever the mouse cursor is within its boundary, so the events need to
     // be attached to children too.
-    child->Connect(wxEVT_ENTER_WINDOW, wxMouseEventHandler(wxRibbonPanel::OnMouseEnterChild), NULL, this);
-    child->Connect(wxEVT_LEAVE_WINDOW, wxMouseEventHandler(wxRibbonPanel::OnMouseLeaveChild), NULL, this);
+    child->Bind(wxEVT_ENTER_WINDOW, &wxRibbonPanel::OnMouseEnterChild, this);
+    child->Bind(wxEVT_LEAVE_WINDOW, &wxRibbonPanel::OnMouseLeaveChild, this);
 }
 
 void wxRibbonPanel::RemoveChild(wxWindowBase *child)
 {
-    child->Disconnect(wxEVT_ENTER_WINDOW, wxMouseEventHandler(wxRibbonPanel::OnMouseEnterChild), NULL, this);
-    child->Disconnect(wxEVT_LEAVE_WINDOW, wxMouseEventHandler(wxRibbonPanel::OnMouseLeaveChild), NULL, this);
+    child->Unbind(wxEVT_ENTER_WINDOW, &wxRibbonPanel::OnMouseEnterChild, this);
+    child->Unbind(wxEVT_LEAVE_WINDOW, &wxRibbonPanel::OnMouseLeaveChild, this);
 
     wxRibbonControl::RemoveChild(child);
 }
@@ -303,8 +300,8 @@ bool wxRibbonPanel::IsMinimised(wxSize at_size) const
     if(!m_minimised_size.IsFullySpecified())
         return false;
 
-    return (at_size.GetX() <= m_minimised_size.GetX() &&
-        at_size.GetY() <= m_minimised_size.GetY()) ||
+    return (at_size.GetX() < m_minimised_size.GetX() &&
+        at_size.GetY() < m_minimised_size.GetY()) ||
         at_size.GetX() < m_smallest_unminimised_size.GetX() ||
         at_size.GetY() < m_smallest_unminimised_size.GetY();
 }
@@ -352,7 +349,7 @@ wxSize wxRibbonPanel::GetBestSizeForParentSize(const wxSize& parentSize) const
         wxRibbonControl* control = wxDynamicCast(win, wxRibbonControl);
         if (control)
         {
-            wxClientDC temp_dc((wxRibbonPanel*) this);
+            wxClientDC temp_dc(const_cast<wxRibbonPanel*>(this));
             wxSize clientParentSize = m_art->GetPanelClientSize(temp_dc, this, parentSize, NULL);
             wxSize childSize = control->GetBestSizeForParentSize(clientParentSize);
             wxSize overallSize = m_art->GetPanelSize(temp_dc, this, childSize, NULL);
@@ -374,7 +371,7 @@ wxSize wxRibbonPanel::DoGetNextSmallerSize(wxOrientation direction,
 
     if(m_art != NULL)
     {
-        wxClientDC dc((wxRibbonPanel*) this);
+        wxClientDC dc(const_cast<wxRibbonPanel*>(this));
         wxSize child_relative = m_art->GetPanelClientSize(dc, this, relative_to, NULL);
         wxSize smaller(-1, -1);
         bool minimise = false;
@@ -495,7 +492,7 @@ wxSize wxRibbonPanel::DoGetNextLargerSize(wxOrientation direction,
 
     if(m_art != NULL)
     {
-        wxClientDC dc((wxRibbonPanel*) this);
+        wxClientDC dc(const_cast<wxRibbonPanel*>(this));
         wxSize child_relative = m_art->GetPanelClientSize(dc, this, relative_to, NULL);
         wxSize larger(-1, -1);
 
@@ -587,14 +584,14 @@ wxSize wxRibbonPanel::GetMinNotMinimisedSize() const
     // Ask sizer if present
     if(GetSizer())
     {
-        wxClientDC dc((wxRibbonPanel*) this);
+        wxClientDC dc(const_cast<wxRibbonPanel*>(this));
         return m_art->GetPanelSize(dc, this, GetPanelSizerMinSize(), NULL);
     }
     else if(GetChildren().GetCount() == 1)
     {
         // Common case of single child taking up the entire panel
         wxWindow* child = GetChildren().Item(0)->GetData();
-        wxClientDC dc((wxRibbonPanel*) this);
+        wxClientDC dc(const_cast<wxRibbonPanel*>(this));
         return m_art->GetPanelSize(dc, this, child->GetMinSize(), NULL);
     }
 
@@ -615,7 +612,7 @@ wxSize wxRibbonPanel::GetPanelSizerMinSize() const
          return GetSizer()->CalcMin();
     }
     // else use previously calculated m_smallest_unminimised_size
-    wxClientDC dc((wxRibbonPanel*) this);
+    wxClientDC dc(const_cast<wxRibbonPanel*>(this));
     return m_art->GetPanelClientSize(dc,
                                     this,
                                     m_smallest_unminimised_size,
@@ -636,14 +633,14 @@ wxSize wxRibbonPanel::DoGetBestSize() const
     // Ask sizer if present
     if( GetSizer())
     {
-        wxClientDC dc((wxRibbonPanel*) this);
+        wxClientDC dc(const_cast<wxRibbonPanel*>(this));
         return m_art->GetPanelSize(dc, this, GetPanelSizerBestSize(), NULL);
     }
     else if(GetChildren().GetCount() == 1)
     {
         // Common case of no sizer and single child taking up the entire panel
         wxWindow* child = GetChildren().Item(0)->GetData();
-        wxClientDC dc((wxRibbonPanel*) this);
+        wxClientDC dc(const_cast<wxRibbonPanel*>(this));
         return m_art->GetPanelSize(dc, this, child->GetBestSize(), NULL);
     }
 
@@ -696,11 +693,15 @@ bool wxRibbonPanel::Realize()
         wxSize panel_min_size = GetMinNotMinimisedSize();
         m_minimised_size = m_art->GetMinimisedPanelMinimumSize(temp_dc, this,
             &bitmap_size, &m_preferred_expand_direction);
-        if(m_minimised_icon.IsOk() && m_minimised_icon.GetSize() != bitmap_size)
+        if(m_minimised_icon.IsOk() && m_minimised_icon.GetLogicalSize() != bitmap_size)
         {
+            double scale = m_minimised_icon.GetScaleFactor();
+            if (scale > 1.0)
+                scale = 2.0;
+
             wxImage img(m_minimised_icon.ConvertToImage());
-            img.Rescale(bitmap_size.GetWidth(), bitmap_size.GetHeight(), wxIMAGE_QUALITY_HIGH);
-            m_minimised_icon_resized = wxBitmap(img);
+            img.Rescale(int(scale * bitmap_size.GetWidth()), int(scale * bitmap_size.GetHeight()), wxIMAGE_QUALITY_HIGH);
+            m_minimised_icon_resized = wxBitmap(img, -1, scale);
         }
         else
         {
@@ -906,9 +907,8 @@ void wxRibbonPanel::OnKillFocus(wxFocusEvent& evt)
         if(IsAncestorOf(this, receiver))
         {
             m_child_with_focus = receiver;
-            receiver->Connect(wxEVT_KILL_FOCUS,
-                wxFocusEventHandler(wxRibbonPanel::OnChildKillFocus),
-                NULL, this);
+            receiver->Bind(wxEVT_KILL_FOCUS,
+                &wxRibbonPanel::OnChildKillFocus, this);
         }
         else if(receiver == NULL || receiver != m_expanded_dummy)
         {
@@ -922,16 +922,16 @@ void wxRibbonPanel::OnChildKillFocus(wxFocusEvent& evt)
     if(m_child_with_focus == NULL)
         return; // Should never happen, but a check can't hurt
 
-    m_child_with_focus->Disconnect(wxEVT_KILL_FOCUS,
-      wxFocusEventHandler(wxRibbonPanel::OnChildKillFocus), NULL, this);
+    m_child_with_focus->Unbind(wxEVT_KILL_FOCUS,
+      &wxRibbonPanel::OnChildKillFocus, this);
     m_child_with_focus = NULL;
 
     wxWindow *receiver = evt.GetWindow();
     if(receiver == this || IsAncestorOf(this, receiver))
     {
         m_child_with_focus = receiver;
-        receiver->Connect(wxEVT_KILL_FOCUS,
-            wxFocusEventHandler(wxRibbonPanel::OnChildKillFocus), NULL, this);
+        receiver->Bind(wxEVT_KILL_FOCUS,
+            &wxRibbonPanel::OnChildKillFocus, this);
         evt.Skip();
     }
     else if(receiver == NULL || receiver != m_expanded_dummy)
