@@ -1,9 +1,7 @@
-
 import wx
-from six import print_
 
-print_(wx.version())
-#import os; print_('PID:', os.getpid()); raw_input('Ready to start, press enter...')
+print(wx.version())
+#import os; print('PID:', os.getpid()); raw_input('Ready to start, press enter...')
 
 
 class MyFrame(wx.Frame):
@@ -13,21 +11,21 @@ class MyFrame(wx.Frame):
         wx.CallAfter(self.after, 1, 2, 3)
 
     def after(self, a, b, c):
-        print_('Called via wx.CallAfter:', a, b, c)
+        print('Called via wx.CallAfter:', a, b, c)
 
     def onSize(self, evt):
-        print_(repr(evt.Size))
+        print(repr(evt.Size))
         evt.Skip()
 
 class MyApp(wx.App):
     def OnInit(self):
-        print_('OnInit')
+        print('OnInit')
         frm = MyFrame(None, title="Hello with Events", size=(480,360))
         frm.Show()
         return True
 
     def OnExit(self):
-        print_('OnExit')
+        print('OnExit')
         return 0
 
 app = MyApp()
