@@ -28,7 +28,7 @@ class dialog_Tests(wtc.WidgetTestCase):
 
     def test_dialogDefaultCtor(self):
         dlg = wx.Dialog()
-        dlg.Create(None, title='dialog')
+        dlg.Create(self.frame, title='dialog')
         self.runDialog(dlg)
 
     def test_dialog1(self):
@@ -36,10 +36,6 @@ class dialog_Tests(wtc.WidgetTestCase):
         dlg = wx.Dialog(self.frame, title='Hello')
         self.runDialog(dlg)
 
-    def test_dialog2(self):
-        # without parent
-        dlg = wx.Dialog(None, title='World')
-        self.runDialog(dlg)
 
     def test_dialogTextSizer(self):
         dlg = wx.Dialog(self.frame, title='Hello')
